@@ -8,10 +8,12 @@ from meiga.decorators import meiga
 from yaml.parser import ParserError, ScannerError
 
 from petisco.application.config.config_persistence import ConfigPersistence
+from petisco.application.config.config_providers import ConfigProviders
+from petisco.application.config.cron.config_cron import ConfigCron
 from petisco.frameworks.interface_application import IApplication
 from petisco.logger.interface_logger import ILogger
 from petisco.logger.logging_based_logger import LoggingBasedLogger
-from petisco.application.config.config_infrastructure import ConfigInfrastructure
+from petisco.application.config.events.config_events import ConfigEvents
 from petisco.application.config.config_file_not_found_error import (
     ConfigFileNotFoundError,
 )
@@ -29,19 +31,23 @@ class Config:
         app_name: str,
         app_version: str,
         petisco_yml_folder: str = None,
+        config_cron: ConfigCron = None,
         config_framework: ConfigFramework = None,
         config_logger: ConfigLogger = None,
         config_persistence: ConfigPersistence = None,
-        config_infrastructure: ConfigInfrastructure = None,
+        config_providers: ConfigProviders = None,
+        config_events: ConfigEvents = None,
         options: Dict = None,
     ):
         self.app_name = app_name
         self.app_version = app_version
         self.petisco_yml_folder = petisco_yml_folder
+        self.config_cron = config_cron
         self.config_framework = config_framework
         self.config_logger = config_logger
         self.config_persistence = config_persistence
-        self.config_infrastructure = config_infrastructure
+        self.config_providers = config_providers
+        self.config_events = config_events
         self.options = options
 
     @staticmethod
@@ -70,6 +76,8 @@ class Config:
             petisco_yml_folder, app_config.get("version")
         ).unwrap_or_return()
 
+        config_cron = ConfigCron.from_dict(yaml_dict.get("cron"))
+
         config_framework = ConfigFramework.from_dict(yaml_dict.get("framework"))
 
         config_logger = Config.get_config_logger(
@@ -78,9 +86,9 @@ class Config:
 
         config_persistence = ConfigPersistence.from_dict(yaml_dict.get("persistence"))
 
-        config_infrastructure = ConfigInfrastructure.from_dict(
-            yaml_dict.get("infrastructure")
-        )
+        config_providers = ConfigProviders.from_dict(yaml_dict.get("providers"))
+
+        config_events = ConfigEvents.from_dict(yaml_dict.get("events"))
 
         options = app_config.get("options")
 
@@ -89,9 +97,11 @@ class Config:
                 petisco_yml_folder=petisco_yml_folder,
                 app_name=app_name,
                 app_version=app_version,
+                config_cron=config_cron,
                 config_framework=config_framework,
                 config_logger=config_logger,
-                config_infrastructure=config_infrastructure,
+                config_providers=config_providers,
+                config_events=config_events,
                 config_persistence=config_persistence,
                 options=options,
             )
@@ -118,7 +128,7 @@ class Config:
                     )
                 )
             version = open(version_filename, "r").read()
-            return Success(version)
+            return Success(version.rstrip("\n"))
 
     @staticmethod
     def get_config_logger(config_logger_dict: Dict) -> Result[ConfigLogger, Error]:
@@ -135,7 +145,7 @@ class Config:
             return LoggingBasedLogger(
                 logger_name=self.config_logger.name,
                 format=self.config_logger.format,
-                config_func=self.config_logger.get_config_func(),
+                config=self.config_logger.config,
             )
 
     def get_application(self) -> IApplication:
