@@ -22,7 +22,18 @@ from petisco.domain.value_objects.client_id import ClientId
 from petisco.domain.value_objects.user_id import UserId
 from petisco.domain.value_objects.correlation_id import CorrelationId
 from petisco.domain.value_objects.value_object import ValueObject
-from petisco.events.event_config import EventConfig
+from petisco.events.publisher.domain.interface_event_publisher import IEventPublisher
+from petisco.events.publisher.infrastructure.not_implemented_event_publisher import (
+    NotImplementedEventPublisher,
+)
+from petisco.events.subscriber.domain.config_event_subscriber import (
+    ConfigEventSubscriber,
+)
+from petisco.events.subscriber.domain.interface_event_subscriber import IEventSubscriber
+from petisco.events.subscriber.domain.subscriber_handler import subscriber_handler
+from petisco.events.subscriber.infrastructure.not_implemented_event_subscriber import (
+    NotImplementedEventSubscriber,
+)
 from petisco.frameworks.interface_application import IApplication
 from petisco.logger.logging_based_logger import LoggingBasedLogger
 from petisco.logger.interface_logger import ILogger
@@ -38,10 +49,9 @@ from petisco.use_case import UseCase
 from petisco.use_case import use_case_handler
 from petisco.controller.controller_handler import controller_handler
 from petisco.controller.errors.http_error import HttpError
-from petisco.events.event import Event
+from petisco.events.event import Event, Events
 from petisco.events.event_id import EventId
-from petisco.events.interface_event_manager import IEventManager
-from petisco.events.not_implemented_event_manager import NotImplementedEventManager
+
 
 classes = [
     "IService",
@@ -55,9 +65,8 @@ classes = [
     "LoggingBasedLogger",
     "ILogger",
     "Event",
+    "Events",
     "EventId",
-    "IEventManager",
-    "NotImplementedEventManager",
     "Singleton",
     "TokenManager",
     "NotImplementedTokenManager",
@@ -70,13 +79,18 @@ classes = [
     "ClientId",
     "UserId",
     "InfoId",
-    "EventConfig",
     "AggregateRoot",
     "Petisco",
     "IApplication",
     "Config",
     "EmptyValueObjectError",
     "ExceedLengthLimitValueObjectError",
+    "subscriber_handler",
+    "ConfigEventSubscriber",
+    "IEventPublisher",
+    "IEventSubscriber",
+    "NotImplementedEventPublisher",
+    "NotImplementedEventSubscriber",
 ]
 
 # Controllers & Use Cases
@@ -151,36 +165,24 @@ try:
 except (RuntimeError, ImportError):
     sqlalchemy = []
 
-# Redis
+# RabbitMQ
 try:
-    from petisco.events.redis.redis_event_manager import RedisEventManager
-    from petisco.events.redis.event_from_redis_message import (
-        event_from_redis_message,
-        EventFromRedisMessageConversionError,
+    from petisco.events.publisher.infrastructure.rabbitmq_event_publisher import (
+        RabbitMQEventPublisher,
     )
+    from petisco.events.subscriber.infrastructure.rabbitmq_event_subscriber import (
+        RabbitMQEventSubscriber,
+    )
+    from petisco.events.rabbitmq.rabbitmq_connector import RabbitMQConnector
 
-    redis = [
-        "RedisEventManager",
-        "event_from_redis_message",
-        "EventFromRedisMessageConversionError",
+    rabbitmq = [
+        "RabbitMQEventPublisher",
+        "RabbitMQEventSubscriber",
+        "RabbitMQConnector",
     ]
-except (RuntimeError, ImportError):
-    redis = []
-
-# RabbitMq
-try:
-    from petisco.events.rabbitmq.rabbitmq_event_manager import RabbitMQEventManager
-
-    rabbitmq = ["RabbitMQEventManager"]
 except (RuntimeError, ImportError):
     rabbitmq = []
 
 __all__ = (
-    classes
-    + controllers_and_use_cases
-    + constants
-    + flask
-    + sqlalchemy
-    + redis
-    + rabbitmq
+    classes + controllers_and_use_cases + constants + flask + sqlalchemy + rabbitmq
 )
